@@ -1,11 +1,11 @@
 //! @file a68g-defines.h
 //! @author J. Marcel van der Veer
-//!
+
 //! @section Copyright
 //!
 //! This file is part of Algol68G - an Algol 68 compiler-interpreter.
 //! Copyright 2001-2023 J. Marcel van der Veer [algol68g@xs4all.nl].
-//!
+
 //! @section License
 //!
 //! This program is free software; you can redistribute it and/or modify it 
@@ -19,6 +19,10 @@
 //! more details. You should have received a copy of the GNU General Public 
 //! License along with this program. If not, see [http://www.gnu.org/licenses/].
 
+//! @section Synopsis
+//!
+//! General macro definitions.
+
 #if !defined (__A68G_DEFINES_H__)
 #define __A68G_DEFINES_H__
 
@@ -62,7 +66,6 @@
 // which may give an undefined reference to `__stack_chk_fail_local'.
 // 
 // -Wno-parentheses-equality is needed for OpenBSD.  
-//
 
 #define A68_GCC_OPTIONS "-DA68_OPTIMISE -ggdb -fno-stack-protector -Wno-parentheses-equality"
 
@@ -76,7 +79,7 @@
 
 #define A68_DIR ".a68g"
 #define A68_HISTORY_FILE ".a68g.edit.hist"
-#define A68_NO_FILENO ((FILE_T) -1)
+#define A68_NO_FILE ((FILE_T) -1)
 #define A68_PROTECTION (S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH)  // -rw-r--r--
 #define A68_READ_ACCESS (O_RDONLY)
 #define A68_WRITE_ACCESS (O_WRONLY | O_CREAT | O_TRUNC)
@@ -107,10 +110,6 @@
 #define TRANSPUT_BUFFER_SIZE BUFFER_SIZE
 #define WANT_PATTERN A68_TRUE
 
-#define MANT_DIGS(n) ((int) round ((n) * log10 (2.0)))
-#define MANT_BITS(n) ((int) round ((n) / log10 (2.0)))
-#define REAL_DIGITS MANT_DIGS (REAL_MANT_DIG)
-
 // Macros
 
 #define _SKIP_ { (void) 0;}
@@ -215,24 +214,12 @@
 #define IN_PRELUDE(p) (LINE_NUMBER (p) <= 0)
 #define EOL(c) ((c) == NEWLINE_CHAR || (c) == NULL_CHAR)
 
-#define SIZE_ALIGNED(p) ((int) A68_ALIGN (sizeof (p)))
-#define A68_REF_SIZE (SIZE_ALIGNED (A68_REF))
-#define A68_UNION_SIZE (SIZE_ALIGNED (A68_UNION))
-
-#define A68_SOUND_BYTES(s) ((int) (BITS_PER_SAMPLE (s)) / 8 + (int) (BITS_PER_SAMPLE (s) % 8 == 0 ? 0 : 1))
-#define A68_SOUND_DATA_SIZE(s) ((int) (NUM_SAMPLES (s)) * (int) (NUM_CHANNELS (s)) * (int) (A68_SOUND_BYTES (s)))
 #define BACKWARD(p) (p = PREVIOUS (p))
-#define BITS_WIDTH ((int) (1 + ceil (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 2))))
 #define DEFLEX(p) (DEFLEXED (p) != NO_MOID ? DEFLEXED(p) : (p))
 #define FORWARD(p) ((p) = NEXT (p))
-#define INT_WIDTH ((int) (1 + floor (log ((REAL_T) A68_MAX_INT) / log ((REAL_T) 10))))
-#define LONG_INT_WIDTH (1 + LONG_WIDTH)
 #define PM(m) (moid_to_string (m, 132, NO_NODE))
 #define SIGN(n) ((n) == 0 ? 0 : ((n) > 0 ? 1 : -1))
-#define STATUS_CLEAR(p, q) {STATUS (p) &= (~(q));}
-#define STATUS_SET(p, q) {STATUS (p) |= (q);}
-#define STATUS_TEST(p, q) ((STATUS (p) & (q)) != (unt) 0)
-#define WIS(p) where_in_source (STDOUT_FILENO, (p))
+#define WIS(p) where_in_source (A68_STDOUT, (p))
 #define WRITE(f, s) io_write_string ((f), (s));
 #define WRITELN(f, s) {WRITE ((f), "\n"); WRITE ((f), (s));}
 
@@ -289,7 +276,7 @@
 #define DEVICE_OPENED(p) ((p)->device_opened)
 #define DIAGNOSTICS(p) ((p)->diagnostics)
 #define DIGITS(p) ((p)->digits)
-#define DIGITSC(p) ((p)->digitsc)
+#define DIGITS_COMPL(p) ((p)->digits_compl)
 #define DIM(p) ((p)->dim)
 #define DISPLAY(p) ((p)->display)
 #define DRAW(p) ((p)->draw)
@@ -567,7 +554,7 @@
 #define SIZE(p) ((p)->size)
 #define SIZE1(p) ((p)->size1)
 #define SIZE2(p) ((p)->size2)
-#define SIZEC(p) ((p)->sizec)
+#define SIZE_COMPL(p) ((p)->size_compl)
 #define SLICE(p) ((p)->slice)
 #define SLICE_OFFSET(p) ((p)->slice_offset)
 #define SO(p) ((p)->so)
